@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP11;
 use vars '$VERSION';
-$VERSION = '3.11';
+$VERSION = '3.12';
   #!!!
 
 use Log::Report 'xml-compile-soap';
@@ -366,7 +366,6 @@ sub _flatten_multidim($$$)
 sub rpcDecode(@)
 {   my $self  = shift;
     my @nodes = grep $_->isa('XML::LibXML::Element'), @_;
-main::stamp('decoding');
     my $data  = $self->_dec(\@nodes);
 
 #XXX MO: no idea why this is needed:
@@ -377,7 +376,6 @@ foreach my $d (@$data)
 #use Data::Dumper;
 #warn "RAW DATA=", Dumper $data;
  
-main::stamp('get ids');
     my ($index, $hrefs) = ({}, []);
     $self->_dec_find_ids_hrefs($index, $hrefs, \$data);
     $self->_dec_resolve_hrefs($index, $hrefs);
@@ -478,7 +476,6 @@ sub _dec_typed($$$)
 {   my ($self, $node, $type, $index) = @_;
 
     my $full = type_of_node $node;
-main::stamp("dec typed $full");
     my $read = $self->_dec_reader($node, $type);
 
     my $child = $read->($node);
